@@ -1,6 +1,6 @@
 package Mail::BIMI::Error;
 # ABSTRACT: Class to represent an error condition
-our $VERSION = '3.20230607'; # VERSION
+our $VERSION = '3.20230913'; # VERSION
 use 5.20.0;
 use Moose;
 use Moose::Util::TypeConstraints;
@@ -43,6 +43,8 @@ my %ERROR_MAP = (
   VMC_PARSE_ERROR          => { description => 'Could not parse VMC' },
   VMC_REQUIRED             => { description => 'VMC is required' },
   VMC_VALIDATION_ERROR     => { description => 'VMC did not validate' },
+  VMC_NO_EXPERIMENTAL      => { description => 'Experimental VMC not accepted here' },
+  VMC_DISALLOWED_TYPE      => { description => 'VMC Mark Type not supported here' },
 );
 
 has code => ( is => 'ro', isa => enum([sort keys %ERROR_MAP]), required => 1,
@@ -75,7 +77,7 @@ Mail::BIMI::Error - Class to represent an error condition
 
 =head1 VERSION
 
-version 3.20230607
+version 3.20230913
 
 =head1 DESCRIPTION
 
