@@ -1,6 +1,6 @@
 package Mail::BIMI::VMC;
 # ABSTRACT: Class to model a VMC
-our $VERSION = '3.20230607'; # VERSION
+our $VERSION = '3.20230913'; # VERSION
 use 5.20.0;
 use Moose;
 use Mail::BIMI::Prelude;
@@ -110,6 +110,29 @@ sub subject($self) {
 }
 
 
+sub mark_type($self) {
+  return unless $self->vmc_object;
+
+  # Parse the subject:markType from the subject string
+  # Ideally we could parse the structure, from this
+  # my $subject_entries = $self->vmc_object->x509_object->subject_name->entries;
+  # however the X509 object does not make this easy for a type that is not
+  # compiled in, returning undef for an entry type it does not understand.
+  # So we parse the string instead.
+
+  my $subject = $self->subject;
+  return unless $subject;
+
+  my @subject_entries = split /, ?/, $subject;
+  for my $subject_entry (@subject_entries) {
+    my ($key, $value) = split /= ?/, $subject_entry, 2;
+    next unless $key eq SUBJECT_MARK_TYPE_OID || $key eq 'markType';
+    return $value;
+  }
+  return;
+}
+
+
 sub not_before($self) {
   return if !$self->vmc_object;
   return $self->vmc_object->x509_object->notBefore;
@@ -185,6 +208,23 @@ sub has_valid_usage($self) {
   return $self->vmc_object->has_valid_usage;
 }
 
+
+sub is_experimental($self) {
+  return if !$self->vmc_object;
+  return $self->vmc_object->is_experimental;
+}
+
+
+sub is_allowed_mark_type($self) {
+  my $mark_type = lc $self->mark_type // '';
+  my $allowed_mark_types = lc $self->bimi_object->options->allowed_mark_types;
+  for my $allowed_mark_type (split /, ?/, $allowed_mark_types) {
+    return 1 if $allowed_mark_type eq '*';
+    return 1 if $allowed_mark_type eq $mark_type;
+  }
+  return 0;
+}
+
 sub _build_indicator_uri($self) {
   return if !$self->vmc_object;
   return if !$self->vmc_object->indicator_asn;
@@ -227,6 +267,7 @@ sub _build_is_valid($self) {
   $self->add_error('VMC_EXPIRED','Expired') if $self->is_expired;
   $self->add_error('VMC_VALIDATION_ERROR','Missing usage flag') if !$self->has_valid_usage;
   $self->add_error('VMC_VALIDATION_ERROR','Invalid alt name') if !$self->is_valid_alt_name;
+  $self->add_error('VMC_DISALLOWED_TYPE', 'VMC Mark Type not supported here' ) if !$self->is_allowed_mark_type;
   $self->is_cert_valid;
 
   if ( $self->chain_object && !$self->chain_object->is_valid ) {
@@ -237,6 +278,10 @@ sub _build_is_valid($self) {
     $self->add_error_object( $self->indicator->errors );
   }
 
+  if ( $self->bimi_object->options->no_experimental_vmc && $self->is_experimental ) {
+    $self->add_error('VMC_NO_EXPERIMENTAL','Experimental (V)MCs are not accepted here');
+  }
+
   return 0 if $self->errors->@*;
   $self->log_verbose('VMC is valid');
   return 1;
@@ -252,6 +297,8 @@ sub finish($self) {
 sub app_validate($self) {
   say 'VMC Returned: '.($self->is_valid ? GREEN."\x{2713}" : BRIGHT_RED."\x{26A0}").RESET;
   say YELLOW.'  Subject         '.WHITE.': '.CYAN.($self->subject//'-none-').RESET;
+  say YELLOW.'  Mark Type       '.WHITE.': '.CYAN.($self->mark_type//'-none-').RESET;
+  say YELLOW.'  Is Allowed Type '.WHITE.': '.CYAN.($self->is_allowed_mark_type?GREEN.'Yes':BRIGHT_RED.'No').RESET;
   say YELLOW.'  Not Before      '.WHITE.': '.CYAN.($self->not_before//'-none-').RESET;
   say YELLOW.'  Not After       '.WHITE.': '.CYAN.($self->not_after//'-none-').RESET;
   say YELLOW.'  Issuer          '.WHITE.': '.CYAN.($self->issuer//'-none-').RESET;
@@ -291,7 +338,7 @@ Mail::BIMI::VMC - Class to model a VMC
 
 =head1 VERSION
 
-version 3.20230607
+version 3.20230913
 
 =head1 DESCRIPTION
 
@@ -425,6 +472,10 @@ Maximum permitted HTTP fetch
 
 Return the subject of the VMC
 
+=head2 I<mark_type()>
+
+Return the subject:markType if available
+
 =head2 I<not_before()>
 
 Return not before of the vmc
@@ -457,6 +508,12 @@ Return true if this VMC is self signed
 
 Return true if this VMC has a valid usage extension for BIMI
 
+=head2 I<is_experimental()>
+
+Return true if this (V)MC is experimental
+
+=head2 I<is_allowed_mark_type()>
+
 =head2 I<finish()>
 
 Finish and clean up, write cache if enabled.
